@@ -244,11 +244,5 @@ def searchweb(text,title):
         cef.MessageLoop()
     except:
         return -1
-def alsoprint(text):
-    text=str(text)
-    for i in text:
-        print(i,end='')
-        time.sleep(0.05)
-
 def help():
     print(urllib.request.urlopen("http://www.asunc.cn/alsohelp.txt").read().decode('gbk'))
