@@ -15,11 +15,6 @@ from re import*
 import requests
 from urllib.request import*
 import json
-def getversion():
-    return "0.4.5"
-def cleardevice():
-    print("\033[2J")
-    print("\033[99999999999999999999999999999999A", end='')
 def baidubaike(text):
     html=urllib.request.urlopen("http://gop.asunc.cn/baike.html").read().decode("utf-8")
     url=html+urllib.parse.quote(text)
@@ -117,24 +112,6 @@ def get_news():
         a+=1
     print("\033[0m")
 
-def check_browser_versions():
-    ver = cef.GetVersion()
-    print("[hello_world.py] CEF Python {ver}".format(ver=ver["version"]))
-    print("[hello_world.py] Chromium {ver}".format(ver=ver["chrome_version"]))
-    print("[hello_world.py] CEF {ver}".format(ver=ver["cef_version"]))
-    print("[hello_world.py] Python {ver} {arch}".format(
-           ver=platform.python_version(),
-           arch=platform.architecture()[0]))
-    assert cef.__version__ >= "57.0", "CEF Python v57.0+ required to run this"
-def searchweb(text,title):
-    try:
-        html = urllib.request.urlopen(text).read().decode("utf-8")
-        sys.excepthook = cef.ExceptHook
-        cef.Initialize()
-        cef.CreateBrowserSync(url=text,window_title=title)
-        cef.MessageLoop()
-    except:
-        return -1
 def get_imformation(pid):
     try:
         url="http://code.xueersi.com/api/compilers/"+str(pid)+"?id="+str(pid)
